@@ -3,7 +3,7 @@
                              -------------------
     begin                : Thu Aug 19 2004
     copyright            : (C) 2004, 2006, 2007, 2009, 2010, 2011 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -368,7 +368,7 @@ QString RKConsole::provideContext (int line_rev) {
 	QString ret;
 	if (line_rev == 0) ret = currentEditingLine ().left (currentCursorPositionInCommand ()); 
 	else if (!incomplete_command.isEmpty ()) {
-		QStringList lines = incomplete_command.split ("\n");
+		QStringList lines = incomplete_command.split ('\n');
 		if (lines.size () > line_rev) {
 			ret = lines[lines.size () - line_rev - 1];
 		}
@@ -458,7 +458,7 @@ void RKConsole::doTabCompletion () {
 	QString current_symbol = current_line.mid (word_start, word_end - word_start);
 
 	// as a very simple heuristic: If the current symbol starts with a quote, we should probably attempt file name completion, instead of symbol name completion
-	if (current_symbol.startsWith ("\"") || current_symbol.startsWith ("\'") || current_symbol.startsWith ("`")) {
+	if (current_symbol.startsWith ('\"') || current_symbol.startsWith ('\'') || current_symbol.startsWith ('`')) {
 		KUrlCompletion comp (KUrlCompletion::FileCompletion);
 		comp.setDir (QDir::currentPath ());
 		comp.makeCompletion (current_symbol.mid (1));
@@ -792,7 +792,7 @@ void RKConsole::userSaveHistory (const KUrl &_url) {
 
 	KTemporaryFile tempfile;
 	tempfile.open ();
-	tempfile.write (QString (commandHistory ().join ("\n") + "\n").toLocal8Bit ().data ());
+	tempfile.write (QString (commandHistory ().join ("\n") + '\n').toLocal8Bit ().data ());
 	tempfile.close ();
 
 	KIO::NetAccess::upload (tempfile.fileName (), url, this);
@@ -803,8 +803,8 @@ QString RKConsole::cleanSelection (const QString &origin) {
 
 	QString ret;
 	ret.reserve (origin.length ());
-	QStringList lines = origin.split ("\n");
-	foreach (QString line, lines) {
+	QStringList lines = origin.split ('\n');
+	foreach (const QString& line, lines) {
 		if (line.startsWith (nprefix)) {
 			ret.append (line.mid (nprefix.length ()));
 		} else if (line.startsWith (iprefix)) {
@@ -825,7 +825,7 @@ void RKConsole::copyCommands () {
 	if (!sel.isValid ()) return;
 
 	// we use this somewhat cumbersome (and inefficient) approach as it should also be correct in case of blockwise selections
-	QStringList command_lines = view->selectionText ().split ("\n");
+	QStringList command_lines = view->selectionText ().split ('\n');
 	int i = 0;
 	for (int l = sel.start ().line (); l <= sel.end ().line (); ++l) {
 		QString line = doc->line (l);
@@ -880,9 +880,11 @@ void RKConsole::copyLinesToOutput () {
 	RKCommandHighlighter::copyLinesToOutput (view, RKCommandHighlighter::RInteractiveSession);
 }
 
-void RKConsole::showContextHelp () {
+void RKConsole::currentHelpContext (QString* symbol, QString* package) {
 	RK_TRACE (APP);
-	RKHelpSearchWindow::mainHelpSearch ()->getContextHelp (currentEditingLine (), currentCursorPositionInCommand ());
+	Q_UNUSED (package);
+
+	*symbol = RKCommonFunctions::getCurrentSymbol (currentEditingLine (), currentCursorPositionInCommand ());
 }
 
 void RKConsole::initializeActions (KActionCollection *ac) {
@@ -895,7 +897,8 @@ void RKConsole::initializeActions (KActionCollection *ac) {
 #	define REAL_CMD_KEY Qt::MetaModifier
 #endif
 	RKStandardActions::copyLinesToOutput (this, this, SLOT (copyLinesToOutput()));
-	context_help_action = RKStandardActions::functionHelp (this, this, SLOT(showContextHelp()));
+	RKStandardActions::functionHelp (this, this);
+	RKStandardActions::onlineHelp (this, this);
 	run_selection_action = RKStandardActions::runCurrent (this, this, SLOT (runSelection()));
 
 	interrupt_command_action = ac->addAction ("interrupt", this, SLOT (resetConsole()));
@@ -981,7 +984,7 @@ void RKConsole::contextMenuEvent (QContextMenuEvent * event) {
 void RKConsole::activate (bool with_focus) {
 	RK_TRACE (APP);
 
-	// see http://www.mail-archive.com/rkward-devel@lists.sourceforge.net/msg00933.html
+	// see https://mail.kde.org/pipermail/rkward-devel/2010-September/002422.html
 	if (with_focus) view->removeSelection ();
 	RKMDIWindow::activate (with_focus);
 }
